pub struct Violation {
pub path: String,
pub kind: ViolationKind,
}Expand description
One way in which a message departs from the schema.
Fields
path: StringDotted path to the offending element, starting at the message name.
kind: ViolationKindTrait Implementations
impl Eq for Violation
impl StructuralPartialEq for Violation